#' EnrichDO
#' Enrichment analyses including a variety of statistical models and visualization schemes for discovering the disease-gene relationship under biological big data.
#'
#' @name EnrichDO-package
#' @aliases EnrichDO-package EnrichDO
#' @docType package
#' @author Liang cheng, Haixiu Yang, Hongyu Fu
#'
#' Maintainer: Haixiu Yang \email{yanghaixiu@ems.hrbmu.edu.cn}
#' @keywords package
#' @importFrom dplyr %>%
"_PACKAGE"

utils::globalVariables(c("DOID","parent.arr","gene.len","geneRatio","p","gene.arr","level","DOTerm","cg.len","ig.len","DO","log10p","bgRatio","cg","cg.arr","child.arr","child.len", "children","genes","parent.len", "parents","weight.arr","dotermgenes",".EnrichDOenv","doterms"))
